@@ -1,5 +1,5 @@
-from etl_bq_tools.utils.time_execution import get_time_function_execution
 from etl_bq_tools.utils import constants as cons
+from etl_bq_tools.utils.time_execution import get_time_function_execution
 
 
 @get_time_function_execution
@@ -7,13 +7,15 @@ def bq_create_dataset(project_id=None,
                       dataset_id=None,
                       logging=None,
                       key_path=None):
-    """
+    """This method is for create a dataset
+
     :param project_id: String
     :param dataset_id: String
     :param key_path: file.json
     :param logging: object
-    :return:
+    :return: True
     """
+
     from google.cloud import bigquery
     from google.api_core.exceptions import Conflict
     from color_tools import cprint
@@ -38,12 +40,14 @@ def bq_create_dataset(project_id=None,
             cprint(cons.txt_create_dt_success.forma(f"{project_id}.{dataset.dataset_id}"), "yellow")
         else:
             cprint(cons.txt_create_dt_success.forma(f"{project_id}.{dataset.dataset_id}"), "yellow")
+        return True
     except Conflict:
         if logging:
             logging.info(cons.txt_create_dt_error.forma(f"{project_id}.{dataset.dataset_id}"))
             cprint(cons.txt_create_dt_error.format(f"{project_id}.{dataset.dataset_id}"), "yellow")
         else:
             cprint(cons.txt_create_dt_error.format(f"{project_id}.{dataset.dataset_id}"), "yellow")
+        return None
 
 
 @get_time_function_execution
@@ -51,13 +55,15 @@ def bq_delete_dataset(project_id=None,
                       dataset_id=None,
                       logging=None,
                       key_path=None):
-    """
+    """This method is for delete a dataset
+
     :param project_id: String
     :param dataset_id: String
     :param logging: object
     :param key_path: file.json
-    :return:
+    :return: True
     """
+
     from google.cloud import bigquery
     from google.cloud.exceptions import Conflict
     from color_tools import cprint
@@ -80,24 +86,28 @@ def bq_delete_dataset(project_id=None,
             cprint(cons.txt_delete_dt_success.format(dataset_id), "yellow")
         else:
             cprint(cons.txt_delete_dt_success.format(dataset_id), "yellow")
+        return True
     except Conflict:
         if logging:
             logging.info(cons.txt_delete_dt_error.format(f"{project_id}.{dataset_id}"))
             cprint(cons.txt_delete_dt_error.format(f"{project_id}.{dataset_id}"), "yellow")
         else:
             cprint(cons.txt_delete_dt_error.format(f"{project_id}.{dataset_id}"), "yellow")
+        return None
 
 
 @get_time_function_execution
 def bq_list_dataset(project_id=None,
                     logging=None,
                     key_path=None):
-    """
+    """This method is for list a dataset
+
     :param project_id: String
     :param logging: object
     :param key_path: file.json
-    :return:
+    :return: list dataset
     """
+
     from google.cloud import bigquery
 
     client = bigquery.Client(project=project_id)
@@ -128,15 +138,17 @@ def bq_create_table(project_id=None,
                     schema=None,
                     logging=None,
                     key_path=None):
-    """
+    """This method is for create table
+
     :param project_id: String
     :param dataset_id: String
     :param table_id: String
     :param schema: dict
     :param logging: object
     :param key_path: file.json
-    :return:
+    :return: True
     """
+
     from google.cloud import bigquery
     from google.api_core.exceptions import Conflict
     from color_tools import cprint
@@ -164,12 +176,14 @@ def bq_create_table(project_id=None,
             cprint(cons.txt_create_tb_success.format(f"{table.project}.{table.dataset_id}.{table.table_id}"), "yellow")
         else:
             cprint(cons.txt_create_tb_success.format(f"{table.project}.{table.dataset_id}.{table.table_id}"), "yellow")
+        return True
     except Conflict:
         if logging:
             logging.info(cons.txt_create_tb_error.format(f"{table.project}.{table.dataset_id}.{table.table_id}"))
             cprint(cons.txt_create_tb_error.format(f"{table.project}.{table.dataset_id}.{table.table_id}"), "yellow")
         else:
             cprint(cons.txt_create_tb_error.format(f"{table.project}.{table.dataset_id}.{table.table_id}"), "yellow")
+        return None
 
 
 @get_time_function_execution
@@ -177,12 +191,13 @@ def bq_delete_table(project_id=None,
                     table_full_id=None,
                     logging=None,
                     key_path=None):
-    """
+    """This method is for delete table
+
     :param project_id: String
     :param table_full_id: String -> 'project.dataset.table'
     :param logging: object
     :param key_path: file.json
-    :return:
+    :return: True
     """
 
     from google.cloud import bigquery
@@ -201,27 +216,31 @@ def bq_delete_table(project_id=None,
             cprint(cons.txt_delete_tb_success.format(f"{table_id}"), "yellow")
         else:
             cprint(cons.txt_delete_tb_success.format(f"{table_id}"), "yellow")
+        return True
     except Conflict:
         if logging:
             logging.info(cons.txt_delete_tb_error.format(f"{table_id}"))
             cprint(cons.txt_delete_tb_error.format(f"{table_id}"), "yellow")
         else:
             cprint(cons.txt_delete_tb_error.format(f"{table_id}"), "yellow")
+        return None
 
 
 @get_time_function_execution
 def bq_query_to_df(
         project_id=None, sql=None, file=None, use_legacy_sql=False,
         logging=None, key_path=None):
+    """This method is for transform query to dataframe
+
+    :param project_id: String
+    :param sql: String
+    :param file: String file_path.sql
+    :param use_legacy_sql: Boolean
+    :param logging: object
+    :param key_path: file.json
+    :return: Dataframe
     """
-     :param project_id: String
-     :param sql: String
-     :param file: String file_path.sql
-     :param use_legacy_sql: Boolean
-     :param logging: object
-     :param key_path: file.json
-     :return:
-    """
+
     from google.cloud import bigquery
     from color_tools import cprint
 
@@ -262,21 +281,24 @@ def bq_query_to_df(
             cprint(cons.txt_query_to_df_errors, 'yellow')
         else:
             cprint(cons.txt_query_to_df_errors, 'yellow')
+        return None
 
 
 @get_time_function_execution
 def bq_query_to_rows(
         project_id=None, sql=None, file=None, use_legacy_sql=False,
         logging=None, key_path=None):
+    """This method is for transform query to rows
+
+    :param project_id: String
+    :param sql: String
+    :param file: String file_path.sql
+    :param use_legacy_sql: Boolean
+    :param logging: object
+    :param key_path: file.json
+    :return: list rows
     """
-     :param project_id: String
-     :param sql: String
-     :param file: String file_path.sql
-     :param use_legacy_sql: Boolean
-     :param logging: object
-     :param key_path: file.json
-     :return:
-    """
+
     from google.cloud import bigquery
     from color_tools import cprint
 
@@ -317,19 +339,22 @@ def bq_query_to_rows(
             cprint(cons.txt_query_to_rows_errors, 'yellow')
         else:
             cprint(cons.txt_query_to_rows_errors, 'yellow')
+        return None
 
 
 @get_time_function_execution
 def bq_query_truncate(
         project_id=None, table_full_id="",
         logging=None, key_path=None):
+    """This method is for truncate table
+
+    :param project_id: String
+    :param table_full_id: String -> 'project.dataset.table'
+    :param logging: object
+    :param key_path: file.json
+    :return: job result
     """
-     :param project_id: String
-     :param table_full_id: String -> 'project.dataset.table'
-     :param logging: object
-     :param key_path: file.json
-     :return:
-    """
+
     from google.cloud import bigquery
     from color_tools import cprint
 
@@ -359,6 +384,7 @@ def bq_query_truncate(
             cprint(cons.txt_truncate_errors, 'yellow')
         else:
             cprint(cons.txt_truncate_errors, 'yellow')
+        return None
 
 
 @get_time_function_execution
@@ -367,16 +393,18 @@ def bq_query_delete_partition(
         partition_column="_PARTITIONTIME",
         date_initial=None, date_final=None,
         logging=None, key_path=None):
+    """This method is for delete partition table
+
+    :param project_id: String
+    :param table_full_id: String -> 'project.dataset.table'
+    :param partition_column: String
+    :param date_initial: String -> YYYY-MM-DD
+    :param date_final: String -> YYYY-MM-DD
+    :param logging: object
+    :param key_path: file.json
+    :return: job result
     """
-     :param project_id: String
-     :param table_full_id: String -> 'project.dataset.table'
-     :param partition_column: String
-     :param date_initial: String -> YYYY-MM-DD
-     :param date_final: String -> YYYY-MM-DD
-     :param logging: object
-     :param key_path: file.json
-     :return:
-    """
+
     from google.cloud import bigquery
     from color_tools import cprint
 
@@ -414,12 +442,23 @@ def bq_query_delete_partition(
             cprint(cons.txt_delete_partition_errors.format(f"{date_initial}", f"{date_final}"), 'yellow')
         else:
             cprint(cons.txt_delete_partition_errors.format(f"{date_initial}", f"{date_final}"), 'yellow')
+        return None
 
 
 @get_time_function_execution
 def bq_query_restore_table(
         project_id=None, table_full_id="", interval=1,
         logging=None, key_path=None):
+    """This method is for restore table
+
+    :param project_id: String
+    :param table_full_id: String -> 'project.dataset.table'
+    :param interval: String
+    :param logging: object
+    :param key_path: file.json
+    :return: job result
+    """
+
     from google.cloud import bigquery
     from color_tools import cprint
 
@@ -452,3 +491,4 @@ def bq_query_restore_table(
             cprint(cons.txt_restore_table_errors.format(f"{table_full_id}"), 'yellow')
         else:
             cprint(cons.txt_restore_table_errors.format(f"{table_full_id}"), 'yellow')
+        return None
