@@ -1,3 +1,5 @@
+"""This file of constants"""
+
 # bq.py
 txt_set_project_success = "Project update: {0}"
 txt_set_project_errors = "Project Not Found: {0}"
@@ -38,6 +40,9 @@ txt_upload_df_to_bq_success = "Load Table {0} from dataframe"
 txt_upload_df_to_bq_errors = "Provided Schema does not match table {0}"
 
 # cloudstorage
+txt_gs_bucket_list_objects_success = "list_blobs from  bucket {0}"
+txt_gs_bucket_list_objects_errors = "BucketName Not Found {0}"
+
 txt_gs_bucket_list_patterns_success = "list_blobs from  bucket {0}"
 txt_gs_bucket_list_patterns_errors = "BucketName Not Found {0}"
 
@@ -47,7 +52,7 @@ txt_gs_bucket_list_to_df_errors = "BucketName Not Found {0} "
 txt_bucket_download_file_success = "Download file: {0}"
 txt_bucket_download_file_errors = "File Not Found {0}"
 
-txt_bucket_upload_file_success = "Download file: {0}"
+txt_bucket_upload_file_success = "Upload file: {0}"
 txt_bucket_upload_file_errors = "File Not Found {0}"
 
 txt_storage_delete_file_success = "Delete file: {0}"
