@@ -1,4 +1,11 @@
 def get_reduce_memory(dataset, verbose=True):
+    """This method is for reduce memory dataframe
+
+    :param dataset: Dataframe
+    :param verbose: Boolean
+    :return: Dataframe
+    """
+
     import numpy as np
     import pandas as pd
 
